@@ -25,7 +25,7 @@ use Encode 'encode_utf8';
 
 use experimental 'postderef';
 
-our $VERSION = "v0.0.18";
+our $VERSION = "v0.0.19";
 
 use constant {
     DEFAULT_CLEANUP_INTERVAL          => 5,
@@ -55,9 +55,9 @@ sub register ($self, $app, $config) {
     my $db_string = $config->{'db_string'} or die "missing db_string configuration option";
     my $pg = Mojo::Pg->new($db_string);
     BoardStreams::DBMigrations->apply_migrations($pg);
+    $app->helper("$bs_prefix.pg" => sub { $pg });
     $app->helper("$bs_prefix.db" => sub { $pg->db });
     $app->helper("$bs_prefix.pubsub" => sub { $pg->pubsub });
-    $app->helper("$bs_prefix.pubsub_db" => sub { $pg->pubsub->db });
     my $event_patch_sequence_name = $app->$bs_prefix->db->query("
         SELECT pg_get_serial_sequence('event_patch', 'id')
     ")->array->[0];
@@ -226,6 +226,13 @@ sub register ($self, $app, $config) {
                 $txn->commit;
             });
         }
+
+        # Remove this code when this issue has been addressed:
+        #  https://github.com/mojolicious/mojo-pg/issues/77
+        $app->$bs_prefix->pubsub->listen('dummy_notification' => sub {});
+        rx_timer(rand(0.5), 0.5)->subscribe(sub {
+            $app->$bs_prefix->pubsub->notify('dummy_notification' => '{}');
+        });
     });
 
     $app->helper("$bs_prefix.on_action", sub ($c, $channel_name, $action_name, $action_sub) {
